==> pywebuml-0.1.3.zip: pywebuml-0.1.3/setup.py <==
from setuptools import setup, find_packages
import os

here = os.path.dirname(__file__)
README = open(os.path.join(here, 'README.rst')).read()
NEWS = open(os.path.join(here, 'NEWS.txt')).read()

version = '0.1.3'

install_requires = [
    # List your project dependencies here.
    # For more details, see:
    # http://packages.python.org/distribute/setuptools.html#declaring-dependencies
    'Flask',
    'Flask-SQLAlchemy',
    'unittest2',
]


setup(name='pywebuml',
    version=version,
    description="Creates UML diagrams from code",
    long_description=README + '\n\n' + NEWS,
    classifiers=[
      "Development Status :: 4 - Beta",
      "Programming Language :: Java",
      "Programming Language :: C#",
      "Topic :: Documentation",
      "Topic :: Software Development :: Documentation",
      "Intended Audience :: Developers",
      "License :: OSI Approved :: BSD License",
      "Operating System :: OS Independent",
      "Programming Language :: Python :: 2.7"

      # Get strings from http://pypi.python.org/pypi?%3Aaction=list_classifiers
    ],
    keywords='uml',
    author='Tomas Zulberti',
    author_email='tzulberti@gmail.com',
    url='http://bitbucket.org/tzulberti/pywebuml',
    license='BSD',
    packages=find_packages('src'),
    package_dir = {'': 'src'},
    package_data = {
        'pywebuml': [
            'templates/*',
            'static/js/*',
            'static/tmp_dir/*',
            'static/images/*',
            'static/css/*.css',
            'static/smothness/*.css',
            'static/smothness/images/*',
        ]
    },
    include_package_data=True,
    zip_safe=False,
    install_requires=install_requires,
    entry_points={
        'console_scripts':
            ['pywebuml=pywebuml.commands:main']
    }
)

==> pywebuml-0.1.4.zip: pywebuml-0.1.4/setup.py <==
from setuptools import setup, find_packages
import os

here = os.path.dirname(__file__)
README = open(os.path.join(here, 'README.rst')).read()
CHANGES = open(os.path.join(here, 'CHANGES.rst')).read()

version = '0.1.4'

install_requires = [
    # List your project dependencies here.
    # For more details, see:
    # http://packages.python.org/distribute/setuptools.html#declaring-dependencies
    'Flask',
    'Flask-SQLAlchemy',
    'unittest2',
]


setup(
    name = 'pywebuml',
    version = version,
    description = "Creates UML diagrams from code",
    long_description = README + '\n\n' + CHANGES,
    classifiers = [
      "Development Status :: 4 - Beta",
      "Programming Language :: Java",
      "Programming Language :: C#",
      "Topic :: Documentation",
      "Topic :: Software Development :: Documentation",
      "Intended Audience :: Developers",
      "License :: OSI Approved :: BSD License",
      "Operating System :: OS Independent",
      "Programming Language :: Python :: 2.7"

      # Get strings from http://pypi.python.org/pypi?%3Aaction=list_classifiers
    ],
    keywords = 'uml',
    author = 'Tomas Zulberti',
    author_email = 'tzulberti@gmail.com',
    url = 'http://bitbucket.org/tzulberti/pywebuml',
    license = 'BSD',
    packages = find_packages(exclude=['tests']),
    include_package_data = True,
    install_requires = install_requires,
    zip_safe = False,
    entry_points= {
        'console_scripts':
            ['pywebuml=pywebuml.commands:main']
    }
)
